pub struct SetInternalData {
pub mcaptcha: HashMap<String, MCaptcha>,
}Expand description
Sets internal Captcha data
Fields
mcaptcha: HashMap<String, MCaptcha>Trait Implementations
Sourceimpl Handler<SetInternalData> for Master
impl Handler<SetInternalData> for Master
Sourcetype Result = MessageResult<SetInternalData>
type Result = MessageResult<SetInternalData>
The type of value that this handler will return. Read more
Sourceimpl Handler<SetInternalData> for Master
impl Handler<SetInternalData> for Master
Sourcetype Result = MessageResult<SetInternalData>
type Result = MessageResult<SetInternalData>
The type of value that this handler will return. Read more